This is an automated email from the git hooks/post-receive script.

thansen pushed a commit to branch master
in repository aseprite.

commit 2fcd2b40137c09ea6b55cfc6165616af09aba397
Author: David Capello <[email protected]>
Date:   Fri Dec 11 15:11:34 2015 -0300

    Copy user data when a layer is duplicated
---
 src/app/document.cpp | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/src/app/document.cpp b/src/app/document.cpp
index 839e415..2f5474d 100644
--- a/src/app/document.cpp
+++ b/src/app/document.cpp
@@ -282,9 +282,10 @@ void Document::copyLayerContent(const Layer* sourceLayer0, 
Document* destDoc, La
     dstFlags = (LayerFlags)((int)dstFlags & 
~(int)(LayerFlags::BackgroundLayerFlags));
   }
 
   // Copy the layer name
   destLayer0->setName(sourceLayer0->name());
   destLayer0->setFlags(dstFlags);
+  destLayer0->setUserData(sourceLayer0->userData());
 
   if (sourceLayer0->isImage() && destLayer0->isImage()) {
     const LayerImage* sourceLayer = static_cast<const 
@@ -282,9 +282,10 @@ void Document::copyLayerContent(const Layer* sourceLayer0, 
   }
 
-  // Copy the layer name
+  // Copy the layer name/flags/user data
   destLayer0->setName(sourceLayer0->name());
   destLayer0->setFlags(dstFlags);
LayerImage*>(sourceLayer0);

-- 
Alioth's /usr/local/bin/git-commit-notice on 
/srv/git.debian.org/git/pkg-games/aseprite.git

_______________________________________________
Pkg-games-commits mailing list
[email protected]
http://lists.alioth.debian.org/cgi-bin/mailman/listinfo/pkg-games-commits

Reply via email to